Documentation
¶
Overview ¶
Package cmd Copyright © 2022 Carbonetes eng@carbonetes.com
Index ¶
Constants ¶
This section is empty.
Variables ¶
Functions ¶
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.
func ValidateOutputArg ¶
func ValidateOutputArg(outputType string)
ValidateOutputArg checks if output types specified are valid
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.